Version 0.4.0
-------------
* Added support for the Geckoboard service.

Version 0.3.0
-------------
* Added support for the Performable service.

Version 0.2.0
-------------
* Added support for the HubSpot service.
* Added template tags for individual services.

Version 0.1.0
-------------
* First project release.
